tlslite.constants.AlertLevel

Home | Trees | Indices | Help |
--- | --- | --- | --- | ---

Package tlslite :: Module constants :: Class AlertLevel |
[hide private]
[frames] | no frames]

# Class AlertLevel

source code

Class Variables | [hide private]
| fatal = `2`
| warning = `1`

Home | Trees | Indices | Help |
--- | --- | --- | --- | ---

Generated by Epydoc 3.0.1 on Thu Sep 27 16:50:11 2012 | http://epydoc.sourceforge.net